#!/bin/csh -f
#
# install_cgplus.com
#
# script for install GAMESSPLUS based on GAMESS to CHARMM
#-------------------------------------------------------------------------------
#
# Enviromental variables defined by the script install.com of CHARMM:
#
#       chmroot = CHARMM programm directoy
#
#
# Enviromental variables defined by hand by the user following the GAMESSPLUS
# installation steps
#
#       gms     = GAMESS program directory
#       gmsplus = GAMSSPLUS programm directory
#
#-------------------------------------------------------------------------------
#
# Definition of variables 
#
#       chmsrc     = directory where the CHARMM source code files are stored
#       gmssrc     = directory where the GAMESS source code files are stored
#       chmgms     = directory where the GAMESS source stored to CHARMM
#       gpssrc     = directory where the GAMESSPLUS source code files are stored
#       cgplus     = directory where the CGPLUS utility are stored
#       chmbld     = directory where CHARMM is build
#
#  set gamess = ~/gamess_3July03
#  set gmsplus = ~/gmsplus-v4.1
#  set chmroot = ~/c30a1_gmsplus4.1
#  set cgplus = ~/cgplus-v1.0
  set gamess = ~/tmp/gamess
  set gmsplus = ~/tmp/gmsplus-v2008
  set chmroot = ~/tmp/c30a1
  set cgplus = ~/tmp/cgplus-v2008
#
  set gmssrc = $gamess/source
  set gpssrc = $gmsplus/Code
  set chmsrc = $chmroot/source
  set chmgms = $chmsrc/gamint/gamess
  set chmbld = $chmroot/build/ibmsp
#
  if ( $#argv == 0 ) then
    echo " "
    echo " Usage: install_cgplus.com "
    echo " "
  endif

#
# Step 1: Copy of the GAMESS source code files and made necessary
#
  echo " === Step 1: Copy GAMESS files ==="
  cd $gmssrc
  if (-d $chmgms) then
  else
    mkdir $chmgms
  endif
  ls -1 *.*  > $chmgms/list
  cd $chmgms
  foreach file (` cat list `)
    cp $gmssrc/$file .
  end
  /bin/rm -f list

#
# Step 2: Copy and Replace of the GAMESSPLUS source code files 
#
  echo " === Step 2: Copy GAMESSPLUS files ==="
  cd $gpssrc
  ls -1 *.src  > $chmgms/list
  cd $chmgms
  foreach file (` cat list `)
    cp $gpssrc/$file .
#
# change GAMESS to a subroutine of GAMESS, and set KCHRMM=1
#
    set name = `echo $file | awk -F. '{print $1}' `
    set exte = `echo $file | awk -F. '{print $2}' `
    if ( $name == 'gamess' ) then
       sed 's/      PROGRAM GAMESS/      SUBROUTINE GAMESS/' $file > $file.tmp
       mv $file.tmp $file

       sed 's/      KCHRMM=0/      KCHRMM=1/' $file > $file.tmp
       mv $file.tmp $file

       sed 's/      NCHMAT=0/C     NCHMAT=0/' $file > $file.tmp
       mv $file.tmp $file

       set nlin = `grep -n 'CALL ENDING' $file | awk -F: '{print $1}'`
       sed -n "1,$nlin p" $file > $file.tmp
       echo "      RETURN" >> $file.tmp
       @ nlin = ($nlin + 2)
       sed -n "$nlin,$ p" $file >> $file.tmp
       mv $file.tmp $file
    endif
#
# mv gho.src to gamint/ compile as a part of the CHARMM/GAMESS interface.
# gho.src follows CHARMM programming convention, need pre-processor 
#
    if ( $name == 'gho' ) then
       mv $file $chmsrc/gamint
    endif
  end
  /bin/rm -f list

#
# Step 3: change -MXCHRM- parameter from 1 to 25120 for all GAMESS and
#         GAMESSPLUS files
#
  echo " === Step 3: Change MXCHRM from 1 to 25120 ==="
  cd $chmgms
  ls -1 *.src  > $chmgms/list
  foreach file (` cat list `)
    sed 's/MXCHRM=1/MXCHRM=25120/' $file > $file.tmp
    mv $file.tmp $file
  end
  /bin/rm -f list

#
# Step 4: Comment dummy routine CHGMIU and CHMDAT in iolib.src
#
  echo " === Step 4: Comment CHGMIU and CHMDAT in iolib.src ==="
  cd $chmgms
  ls -1 *.src  > $chmgms/list
  foreach file (` cat list `)
    set name = `echo $file | awk -F. '{print $1}' `
    set exte = `echo $file | awk -F. '{print $2}' `
    if ( $name == 'iolib' ) then
       set nlin = `grep -n 'SUBROUTINE CHGMIU' $file | awk -F: '{print $1}'`
       @ nlin = ($nlin - 1)
       sed -n "1,$nlin p" $file > $file.tmp
       echo "C     SUBROUTINE CHGMIU" >> $file.tmp
       echo "C     RETURN" >> $file.tmp
       echo "C     END" >> $file.tmp
       echo "C*MODULE IOLIB   *DECK CHMDAT" >> $file.tmp
       echo "C     SUBROUTINE CHMDAT(AATOM,AZNUC,CORD,NAT)" >> $file.tmp
       echo "C     IMPLICIT DOUBLE PRECISION(A-H,O-Z)" >> $file.tmp
       echo "C     CHARACTER*10 AATOM(*)" >> $file.tmp
       echo "C     DIMENSION AZNUC(*),CORD(*)" >> $file.tmp
       echo "C     RETURN" >> $file.tmp
       echo "C     END" >> $file.tmp
       @ nlin = ($nlin + 11)
       sed -n "$nlin,$ p" $file >> $file.tmp
       mv $file.tmp $file
    endif
  end
  /bin/rm -f list

#
# Step 5: Copy and Replace of the CHARMM source code files 
#
  echo " === Step 5: Copy modified CHARMM files ==="
  cd $chmsrc/charmm
  cp $cgplus/charmm_main.src .

  cd $chmsrc/gamint
  cp $cgplus/blur.src .
  cp $cgplus/ddi.src .
  
  cd $chmsrc/gukint
  cp $cgplus/gukini.src .
   
  cd $chmsrc/energy
  cp $cgplus/eintern.src .
  cp $cgplus/enefscal.src .
  
  cd $chmsrc/gener
  cp $cgplus/update.src .

  cd $chmsrc/fcm
  cp $cgplus/ghogms.fcm .
#
# replace MAXGMS = 500 with MAXGMS = 2000 in gamess.fcm 
# to be consistent with the newer version of gamess.
#
  sed 's/MAXGMS = 500/MAXGMS = 2000/' gamess.fcm > gamess.fcm.tmp
  mv gamess.fcm.tmp gamess.fcm
#
#
# Step 6: Copy and Makefiles and gamess compiling tool to CHARMM directory for
#         CHARMM/GAMESSPLUS
#
  echo " === Step 6: Copy make files and the gmscomp tool ==="
#
  cd $cgplus
  echo "# CHARMM makefile for IBM SP systems" > Makefile.tmp
  echo "ROOT = $chmroot" >> Makefile.tmp
  sed -n "3,$ p" Makefile >> Makefile.tmp
#
  cd $chmbld 
  mv $cgplus/Makefile.tmp Makefile
  cp $cgplus/Makefile_ibmsp .
  cp $cgplus/gamess.mk .
  cp $cgplus/gamint.mk .
  cd $chmroot/tool
  cp $cgplus/gmscomp_ibmsp .
#
# Step 7: Remove parallel compiling option from pref.dat
#
  echo " === Step 7: Remove PARALLEL, PARAFULL, and SYNCHRON from pref.dat ===" 
  cd $chmbld
  set file = pref.dat
  set nlin = `grep -n 'PARALLEL' $file | awk -F: '{print $1}'`
  @ nlin = ($nlin - 1)
  sed -n "1,$nlin p" $file > $file.tmp
  @ nlin = ($nlin + 2)
  sed -n "$nlin,$ p" $file >> $file.tmp
  mv $file.tmp $file
#
  set nlin = `grep -n 'PARAFULL' $file | awk -F: '{print $1}'`
  @ nlin = ($nlin - 1)
  sed -n "1,$nlin p" $file > $file.tmp
  @ nlin = ($nlin + 2)
  sed -n "$nlin,$ p" $file >> $file.tmp
  mv $file.tmp $file
#
  set nlin = `grep -n 'SYNCHRON' $file | awk -F: '{print $1}'`
  @ nlin = ($nlin - 1)
  sed -n "1,$nlin p" $file > $file.tmp
  @ nlin = ($nlin + 2)
  sed -n "$nlin,$ p" $file >> $file.tmp
  mv $file.tmp $file
#
  set nlin = `grep -n 'RCFFT' $file | awk -F: '{print $1}'`
  @ nlin = ($nlin - 1)
  sed -n "1,$nlin p" $file > $file.tmp
  @ nlin = ($nlin + 2)
  sed -n "$nlin,$ p" $file >> $file.tmp
  mv $file.tmp $file
#
# go back to the original directory
#
  cd $cgplus
  echo " === Done ==="

